@@ -60,7 +60,7 @@ def git_submodules(git=None):
 
 def get_local_ref(git, branch):
     remote = ":" in branch
-    if not remote and has_local(git, branch):
+    if isinstance(branch, LocalRef) or not remote and has_local(git, branch):
         return branch
     if remote:
         remote_branch = branch.replace(":", "/", 1)
@@ -69,7 +69,7 @@ def get_local_ref(git, branch):
     if not has_remote(git, remote_branch):
         path = git._partial_call_args.get("cwd") or os.getcwd()
         raise MissingRemote(f"git ref '{remote_branch}' not found in {path}")
-    return remote_branch
+    return LocalRef(remote_branch)
 
 
 def origin(branch):
@@ -98,6 +98,10 @@ def has_ref(git, ref):
     return out.exit_code == 0
 
 
+class LocalRef(str):
+    pass
+
+
 class MissingRemote(Exception):
     pass
 
@@ -131,7 +135,10 @@ def git_check_merge(branch1, branch2, git=None):
 
 
 def has_merge_conflict(branch1, branch2, git):
-    return not git_check_merge(branch1, branch2, git=git)
+    try:
+        return not git_check_merge(branch1, branch2, git=git)
+    except MissingRemote:
+        return False
 
 
 def git_bisect_merge_conflict(branch1, branch2, git=None):
